Thanks goes to these wonderful people (`emoji key <https://allcontributors.org/docs/en/emoji-key>`_):

.. raw:: html

    <table class="table table-bordered">
      <tr>
        <!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
        <td align="center">
          <a href="https://github.com/12rambau">
            <img src="https://github.com/12rambau.png" width="70px;" alt="12rambau"/><br />
            <sub><b>Pierrick Rambaud</b></sub>
          </a>
          <br/>
          <a href="#code" title="Code">💻</a>
          <a href="#ideas" title="Ideas, Planning, & Feedback">🤔</a>
          <a href="#question" title="Answering Questions">💬</a>
          <a href="#issue" title="Bug reports">🐛</a>
          <a href="#maintenance" title="Maintenance">🚧</a>
          <a href="#review" title="Reviewed Pull Requests">👀</a>
          <a href="#example" title="Examples">💡</a>
        </td>
        <td align="center">
          <a href="https://github.com/GenevieveBuckley">
            <img src="https://github.com/GenevieveBuckley.png" width="70px;" alt="GenevieveBuckley"/><br />
            <sub><b>Genevieve Buckley</b></sub>
          </a>
          <br/>
          <a href="#code" title="Code">💻</a>
          <a href="#issue" title="Bug reports">🐛</a>
          <a href="#example" title="Examples">💡</a>
        </td>
        <!-- ALL-CONTRIBUTORS-LIST:END -->
      </tr>
    </table>

This project follows the `all-contributors <https://allcontributors.org>`_ specification.

Contributions of any kind are welcome!
